@@ -18,8 +18,8 @@
 */
 
 const execa = require('execa');
-const path = require('path');
-const fs = require('fs-extra');
+const path = require('node:path');
+const fs = require('node:fs');
 const { forgivingWhichSync, isWindows, isDarwin } = require('./utils');
 const java = require('./env/java');
 const { CordovaError, ConfigParser, events } = require('cordova-common');
@@ -110,7 +110,9 @@ module.exports.get_gradle_wrapper = function () {
     let program_dir;
     // OK, This hack only works on Windows, not on Mac OS or Linux.  We will be deleting this eventually!
     if (module.exports.isWindows()) {
-        const result = execa.sync(path.join(__dirname, 'getASPath.bat'));
+        // "shell" option enabled for CVE-2024-27980 (Windows) Mitigation
+        // See https://nodejs.org/en/blog/vulnerability/april-2024-security-releases-2 for more details
+        const result = execa.sync(path.join(__dirname, 'getASPath.bat'), { shell: true });
         // console.log('result.stdout =' + result.stdout.toString());
         // console.log('result.stderr =' + result.stderr.toString());
 
@@ -149,7 +151,7 @@ module.exports.check_gradle = function () {
     const sdkDir = process.env.ANDROID_HOME || process.env.ANDROID_SDK_ROOT;
     if (!sdkDir) {
         return Promise.reject(new CordovaError('Could not find gradle wrapper within Android SDK. Could not find Android SDK directory.\n' +
-            'Might need to install Android SDK or set up \'ANDROID_SDK_ROOT\' env variable.'));
+            'Might need to install Android SDK or set up \'ANDROID_HOME\' env variable.'));
     }
 
     const gradlePath = module.exports.get_gradle_wrapper();
@@ -270,7 +272,7 @@ module.exports.check_android = function () {
                 'Failed to find \'android\' command in your \'PATH\'. Try update your \'PATH\' to include path to valid SDK directory.');
         }
         if (!fs.existsSync(process.env.ANDROID_HOME)) {
-            throw new CordovaError('\'ANDROID_HOME\' environment variable is set to non-existent path: ' + process.env.ANDROID_SDK_ROOT +
+            throw new CordovaError('\'ANDROID_HOME\' environment variable is set to non-existent path: ' + process.env.ANDROID_HOME +
                 '\nTry update it manually to point to valid SDK directory.');
         }
         // Next let's make sure relevant parts of the SDK tooling is in our PATH
@@ -306,7 +308,7 @@ module.exports.run = function () {
     console.log('ANDROID_SDK_ROOT=' + process.env.ANDROID_SDK_ROOT + ' (DEPRECATED)');
 
     return Promise.all([this.check_java(), this.check_android()]).then(function (values) {
-        console.log('Using Android SDK: ' + process.env.ANDROID_SDK_ROOT);
+        console.log('Using Android SDK: ' + (process.env.ANDROID_HOME || process.env.ANDROID_SDK_ROOT));
 
         if (!values[1]) {
             throw new CordovaError('Requirements check failed for Android SDK! Android SDK was not detected.');
@@ -327,7 +329,7 @@ const Requirement = function (id, name, version, installed) {
     this.name = name;
     this.installed = installed || false;
     this.metadata = {
-        version: version
+        version
     };
 };
 
